@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Config.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Config;
 
 use 5.006001;
@@ -26,13 +19,17 @@ use Perl::Critic::Theme qw( $RULE_INVALID_CHARACTER_REGEX cook_rule );
 use Perl::Critic::UserProfile qw();
 use Perl::Critic::Utils qw{
     :booleans :characters :severities :internal_lookup :classification
+    :data_conversion
 };
-use Perl::Critic::Utils::Constants qw{ :profile_strictness };
-use Perl::Critic::Utils::DataConversion qw{ boolean_to_number dor };
+use Perl::Critic::Utils::Constants qw<
+    :profile_strictness
+    $_MODULE_VERSION_TERM_ANSICOLOR
+>;
+use Perl::Critic::Utils::DataConversion qw< boolean_to_number dor >;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '1.088';
+our $VERSION = '1.130';
 
 #-----------------------------------------------------------------------------
 
@@ -62,9 +59,8 @@ sub _init {
     my $errors = Perl::Critic::Exception::AggregateConfiguration->new();
 
     # Construct the UserProfile to get default options.
-    my $profile_source  = $args{-profile}; #Can be file path or data struct
-    my $profile =
-        Perl::Critic::UserProfile->new( -profile => $profile_source );
+    my $profile_source = $args{-profile}; # Can be file path or data struct
+    my $profile = Perl::Critic::UserProfile->new( -profile => $profile_source );
     my $options_processor = $profile->options_processor();
     $self->{_profile} = $profile;
 
@@ -86,22 +82,49 @@ sub _init {
         $options_processor->single_policy(),
         $errors,
     );
+    $self->_validate_and_save_color_severity(
+        'color_severity_highest', $args{'-color-severity-highest'},
+        $options_processor->color_severity_highest(), $errors
+    );
+    $self->_validate_and_save_color_severity(
+        'color_severity_high', $args{'-color-severity-high'},
+        $options_processor->color_severity_high(), $errors
+    );
+    $self->_validate_and_save_color_severity(
+        'color_severity_medium', $args{'-color-severity-medium'},
+        $options_processor->color_severity_medium(), $errors
+    );
+    $self->_validate_and_save_color_severity(
+        'color_severity_low', $args{'-color-severity-low'},
+        $options_processor->color_severity_low(), $errors
+    );
+    $self->_validate_and_save_color_severity(
+        'color_severity_lowest', $args{'-color-severity-lowest'},
+        $options_processor->color_severity_lowest(), $errors
+    );
 
     $self->_validate_and_save_verbosity($args{-verbose}, $errors);
     $self->_validate_and_save_severity($args{-severity}, $errors);
     $self->_validate_and_save_top($args{-top}, $errors);
+    $self->_validate_and_save_theme($args{-theme}, $errors);
+    $self->_validate_and_save_pager($args{-pager}, $errors);
+    $self->_validate_and_save_program_extensions(
+        $args{'-program-extensions'}, $errors);
 
     # If given, these options can be true or false (but defined)
     # We normalize these to numeric values by multiplying them by 1;
-    {
-        $self->{_force} = boolean_to_number( dor( $args{-force}, $options_processor->force() ) );
-        $self->{_only}  = boolean_to_number( dor( $args{-only},  $options_processor->only()  ) );
-        $self->{_color} = boolean_to_number( dor( $args{-color}, $options_processor->color() ) );
-        $self->{_criticism_fatal} =
-          boolean_to_number(dor( $args{'-criticism_fatal'}, $options_processor->criticism_fatal() ) );
-    }
+    $self->{_force} = boolean_to_number( dor( $args{-force}, $options_processor->force() ) );
+    $self->{_only}  = boolean_to_number( dor( $args{-only},  $options_processor->only()  ) );
+    $self->{_color} = boolean_to_number( dor( $args{-color}, $options_processor->color() ) );
+    $self->{_unsafe_allowed} =
+        boolean_to_number(
+            dor( $args{'-allow-unsafe'}, $options_processor->allow_unsafe()
+        ) );
+    $self->{_criticism_fatal} =
+        boolean_to_number(
+            dor( $args{'-criticism-fatal'}, $options_processor->criticism_fatal() )
+        );
 
-    $self->_validate_and_save_theme($args{-theme}, $errors);
 
     # Construct a Factory with the Profile
     my $factory =
@@ -113,6 +136,7 @@ sub _init {
     $self->{_factory} = $factory;
 
     # Initialize internal storage for Policies
+    $self->{_all_policies_enabled_or_not} = [];
     $self->{_policies} = [];
 
     # "NONE" means don't load any policies
@@ -164,12 +188,17 @@ sub _add_policy_if_enabled {
 
     my $config = $policy_object->__get_config()
         or throw_internal
-            q{Policy was not set up properly because it doesn't have }
+            q{Policy was not set up properly because it does not have }
                 . q{a value for its config attribute.};
 
+    push @{ $self->{_all_policies_enabled_or_not} }, $policy_object;
     if ( $policy_object->initialize_if_enabled( $config ) ) {
+        $policy_object->__set_enabled($TRUE);
         push @{ $self->{_policies} }, $policy_object;
     }
+    else {
+        $policy_object->__set_enabled($FALSE);
+    }
 
     return;
 }
@@ -194,6 +223,9 @@ sub _load_policies {
             next;
         }
 
+        # Always exclude unsafe policies, unless instructed not to
+        next if not ( $policy->is_safe() or $self->unsafe_allowed() );
+
         # To load, or not to load -- that is the question.
         my $load_me = $self->only() ? $FALSE : $TRUE;
 
@@ -257,7 +289,7 @@ sub _policy_is_included {
     my ($self, $policy) = @_;
     my $policy_long_name = ref $policy;
     my @inclusions  = $self->include();
-    return any { $policy_long_name =~ m/$_/imx } @inclusions;
+    return any { $policy_long_name =~ m/$_/ixms } @inclusions;
 }
 
 #-----------------------------------------------------------------------------
@@ -266,7 +298,7 @@ sub _policy_is_excluded {
     my ($self, $policy) = @_;
     my $policy_long_name = ref $policy;
     my @exclusions  = $self->exclude();
-    return any { $policy_long_name =~ m/$_/imx } @exclusions;
+    return any { $policy_long_name =~ m/$_/ixms } @exclusions;
 }
 
 #-----------------------------------------------------------------------------
@@ -278,7 +310,7 @@ sub _policy_is_single_policy {
     return if not @patterns;
 
     my $policy_long_name = ref $policy;
-    return any { $policy_long_name =~ m/$_/imx } @patterns;
+    return any { $policy_long_name =~ m/$_/ixms } @patterns;
 }
 
 #-----------------------------------------------------------------------------
@@ -354,7 +386,7 @@ sub _validate_and_save_regex {
 
     my $found_errors;
     foreach my $regex (@regexes) {
-        eval { my $test = qr/$regex/imx; }
+        eval { qr/$regex/ixms }
             or do {
                 my $cleaned_error = $EVAL_ERROR || '<unknown reason>';
                 $cleaned_error =~
@@ -629,102 +661,228 @@ sub _validate_and_save_theme {
     return;
 }
 
+#-----------------------------------------------------------------------------
+
+sub _validate_and_save_pager {
+    my ($self, $args_value, $errors) = @_;
+
+    my $pager;
+    if ( $args_value ) {
+        $pager = defined $args_value ? $args_value : $EMPTY;
+    }
+    elsif ( $ENV{PERLCRITIC_PAGER} ) {
+        $pager = $ENV{PERLCRITIC_PAGER};
+    }
+    else {
+        my $profile = $self->_profile();
+        $pager = $profile->options_processor()->pager();
+    }
+
+    if ($pager eq '$PAGER') {   ## no critic (RequireInterpolationOfMetachars)
+        $pager = $ENV{PAGER};
+    }
+    $pager ||= $EMPTY;
+
+    $self->{_pager} = $pager;
+
+    return;
+}
+
+#-----------------------------------------------------------------------------
+
+sub _validate_and_save_color_severity {
+    my ($self, $option_name, $args_value, $default_value, $errors) = @_;
+
+    my $source;
+    my $color_severity;
+    my $full_option_name;
+
+    if (defined $args_value) {
+        $full_option_name = "-$option_name";
+        $color_severity = lc $args_value;
+    }
+    else {
+        $full_option_name = $option_name;
+        $source = $self->_profile()->source();
+        $color_severity = lc $default_value;
+    }
+    $color_severity =~ s/ \s+ / /xmsg;
+    $color_severity =~ s/ \A\s+ //xms;
+    $color_severity =~ s/ \s+\z //xms;
+    $full_option_name =~ s/ _ /-/xmsg;
+
+    # Should we really be validating this?
+    my $found_errors;
+    if (
+        eval {
+            require Term::ANSIColor;
+            Term::ANSIColor->VERSION( $_MODULE_VERSION_TERM_ANSICOLOR );
+            1;
+        }
+    ) {
+        $found_errors =
+            not Term::ANSIColor::colorvalid( words_from_string($color_severity) );
+    }
+
+    # If we do not have Term::ANSIColor we can not validate, but we store the
+    # values anyway for the benefit of Perl::Critic::ProfilePrototype.
+
+    if ($found_errors) {
+        $errors->add_exception(
+            $self->_new_global_value_exception(
+                option_name     => $full_option_name,
+                option_value    => $color_severity,
+                source          => $source,
+                message_suffix  => 'is not valid.',
+            )
+        );
+    }
+    else {
+        my $option_key = $option_name;
+        $option_key =~ s/ - /_/xmsg;
+
+        $self->{"_$option_key"} = $color_severity;
+    }
+
+    return;
+}
+
+#-----------------------------------------------------------------------------
+
+sub _validate_and_save_program_extensions {
+    my ($self, $args_value, $errors) = @_;
+
+    delete $self->{_program_extensions_as_regexes};
+
+    my $extension_list = q{ARRAY} eq ref $args_value ?
+        [map {words_from_string($_)} @{ $args_value }] :
+        $self->_profile()->options_processor()->program_extensions();
+
+    my %program_extensions = hashify( @{ $extension_list } );
+
+    $self->{_program_extensions} = [keys %program_extensions];
+
+    return;
+
+}
+
 #-----------------------------------------------------------------------------
 # Begin ACCESSSOR methods
 
 sub _profile {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_profile};
 }
 
 #-----------------------------------------------------------------------------
 
+sub all_policies_enabled_or_not {
+    my ($self) = @_;
+    return @{ $self->{_all_policies_enabled_or_not} };
+}
+
+#-----------------------------------------------------------------------------
+
 sub policies {
-    my $self = shift;
+    my ($self) = @_;
     return @{ $self->{_policies} };
 }
 
 #-----------------------------------------------------------------------------
 
 sub exclude {
-    my $self = shift;
+    my ($self) = @_;
     return @{ $self->{_exclude} };
 }
 
 #-----------------------------------------------------------------------------
 
 sub force {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_force};
 }
 
 #-----------------------------------------------------------------------------
 
 sub include {
-    my $self = shift;
+    my ($self) = @_;
     return @{ $self->{_include} };
 }
 
 #-----------------------------------------------------------------------------
 
 sub only {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_only};
 }
 
 #-----------------------------------------------------------------------------
 
 sub profile_strictness {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_profile_strictness};
 }
 
 #-----------------------------------------------------------------------------
 
 sub severity {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_severity};
 }
 
 #-----------------------------------------------------------------------------
 
 sub single_policy {
-    my $self = shift;
+    my ($self) = @_;
     return @{ $self->{_single_policy} };
 }
 
 #-----------------------------------------------------------------------------
 
 sub theme {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_theme};
 }
 
 #-----------------------------------------------------------------------------
 
 sub top {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_top};
 }
 
 #-----------------------------------------------------------------------------
 
 sub verbose {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_verbose};
 }
 
 #-----------------------------------------------------------------------------
 
 sub color {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_color};
 }
 
 #-----------------------------------------------------------------------------
 
+sub pager  {
+    my ($self) = @_;
+    return $self->{_pager};
+}
+
+#-----------------------------------------------------------------------------
+
+sub unsafe_allowed {
+    my ($self) = @_;
+    return $self->{_unsafe_allowed};
+}
+
+#-----------------------------------------------------------------------------
+
 sub criticism_fatal {
-    my $self = shift;
+    my ($self) = @_;
     return $self->{_criticism_fatal};
 }
 
@@ -734,6 +892,65 @@ sub site_policy_names {
     return Perl::Critic::PolicyFactory::site_policy_names();
 }
 
+#-----------------------------------------------------------------------------
+
+sub color_severity_highest {
+    my ($self) = @_;
+    return $self->{_color_severity_highest};
+}
+
+#-----------------------------------------------------------------------------
+
+sub color_severity_high {
+    my ($self) = @_;
+    return $self->{_color_severity_high};
+}
+
+#-----------------------------------------------------------------------------
+
+sub color_severity_medium {
+    my ($self) = @_;
+    return $self->{_color_severity_medium};
+}
+
+#-----------------------------------------------------------------------------
+
+sub color_severity_low {
+    my ($self) = @_;
+    return $self->{_color_severity_low};
+}
+
+#-----------------------------------------------------------------------------
+
+sub color_severity_lowest {
+    my ($self) = @_;
+    return $self->{_color_severity_lowest};
+}
+
+#-----------------------------------------------------------------------------
+
+sub program_extensions {
+    my ($self) = @_;
+    return @{ $self->{_program_extensions} };
+}
+
+#-----------------------------------------------------------------------------
+
+sub program_extensions_as_regexes {
+    my ($self) = @_;
+
+    return @{ $self->{_program_extensions_as_regexes} }
+        if $self->{_program_extensions_as_regexes};
+
+    my %program_extensions = hashify( $self->program_extensions() );
+    $program_extensions{'.PL'} = 1;
+    return @{
+        $self->{_program_extensions_as_regexes} = [
+            map { qr< @{[quotemeta $_]} \z >smx } sort keys %program_extensions
+        ]
+    };
+}
+
 1;
 
 #-----------------------------------------------------------------------------
@@ -742,124 +959,43 @@ __END__
 
 =pod
 
-=for stopwords -params INI-style
+=for stopwords colour INI-style -params
 
 =head1 NAME
 
 Perl::Critic::Config - The final derived Perl::Critic configuration, combined from any profile file and command-line parameters.
 
+
 =head1 DESCRIPTION
 
 Perl::Critic::Config takes care of finding and processing
-user-preferences for L<Perl::Critic>.  The Config object defines which
-Policy modules will be loaded into the Perl::Critic engine and how
-they should be configured.  You should never really need to
-instantiate Perl::Critic::Config directly because the Perl::Critic
-constructor will do it for you.
+user-preferences for L<Perl::Critic|Perl::Critic>.  The Config object
+defines which Policy modules will be loaded into the Perl::Critic
+engine and how they should be configured.  You should never really
+need to instantiate Perl::Critic::Config directly because the
+Perl::Critic constructor will do it for you.
+
+
+=head1 INTERFACE SUPPORT
+
+This is considered to be a non-public class.  Its interface is subject
+to change without notice.
+
 
 =head1 CONSTRUCTOR
 
-=over 8
+=over
 
-=item C<< new( [ -profile => $FILE, -severity => $N, -theme => $string, -include => \@PATTERNS, -exclude => \@PATTERNS, -single-policy => $PATTERN, -top => $N, -only => $B, -profile-strictness => $PROFILE_STRICTNESS_{WARN|FATAL|QUIET}, -force => $B, -verbose => $N, -color => $B, -criticism-fatal => $B] ) >>
-
-=item C<< new() >>
-
-Returns a reference to a new Perl::Critic::Config object.  The default
-value for all arguments can be defined in your F<.perlcriticrc> file.
-See the L<"CONFIGURATION"> section for more information about that.
-All arguments are optional key-value pairs as follows:
-
-B<-profile> is a path to a configuration file. If C<$FILE> is not
-defined, Perl::Critic::Config attempts to find a F<.perlcriticrc>
-configuration file in the current directory, and then in your home
-directory.  Alternatively, you can set the C<PERLCRITIC> environment
-variable to point to a file in another location.  If a configuration
-file can't be found, or if C<$FILE> is an empty string, then all
-Policies will be loaded with their default configuration.  See
-L<"CONFIGURATION"> for more information.
-
-B<-severity> is the minimum severity level.  Only Policy modules that
-have a severity greater than C<$N> will be loaded into this Config.
-Severity values are integers ranging from 1 (least severe) to 5 (most
-severe).  The default is 5.  For a given C<-profile>, decreasing the
-C<-severity> will usually result in more Policy violations.  Users can
-redefine the severity level for any Policy in their F<.perlcriticrc>
-file.  See L<"CONFIGURATION"> for more information.
-
-B<-theme> is special string that defines a set of Policies based on
-their respective themes.  If C<-theme> is given, only policies that
-are members of that set will be loaded.  See the L<"POLICY THEMES">
-section for more information about themes.  Unless the C<-severity>
-option is explicitly given, setting C<-theme> causes the C<-severity>
-to be set to 1.
-
-B<-include> is a reference to a list of string C<@PATTERNS>.  Policies
-that match at least one C<m/$PATTERN/imx> will be loaded into this
-Config, irrespective of the severity settings.  You can use it in
-conjunction with the C<-exclude> option.  Note that C<-exclude> takes
-precedence over C<-include> when a Policy matches both patterns.
-
-B<-exclude> is a reference to a list of string C<@PATTERNS>.  Polices
-that match at least one C<m/$PATTERN/imx> will not be loaded into this
-Config, irrespective of the severity settings.  You can use it in
-conjunction with the C<-include> option.  Note that C<-exclude> takes
-precedence over C<-include> when a Policy matches both patterns.
-
-B<-single-policy> is a string C<PATTERN>.  Only the policy that matches
-C<m/$PATTERN/imx> will be used.  This value overrides the
-C<-severity>, C<-theme>, C<-include>, C<-exclude>, and C<-only>
-options.
-
-B<-top> is the maximum number of Violations to return when ranked by
-their severity levels.  This must be a positive integer.  Violations
-are still returned in the order that they occur within the file.
-Unless the C<-severity> option is explicitly given, setting C<-top>
-silently causes the C<-severity> to be set to 1.
-
-B<-only> is a boolean value.  If set to a true value, Perl::Critic
-will only choose from Policies that are mentioned in the user's
-profile.  If set to a false value (which is the default), then
-Perl::Critic chooses from all the Policies that it finds at your site.
-
-B<-profile-strictness> is an enumerated value, one of
-L<Perl::Critic::Utils::Constants/"$PROFILE_STRICTNESS_WARN"> (the
-default),
-L<Perl::Critic::Utils::Constants/"$PROFILE_STRICTNESS_FATAL">, and
-L<Perl::Critic::Utils::Constants/"$PROFILE_STRICTNESS_QUIET">.  If set
-to L<Perl::Critic::Utils::Constants/"$PROFILE_STRICTNESS_FATAL">,
-Perl::Critic will make certain warnings about problems found in a
-F<.perlcriticrc> or file specified via the B<-profile> option fatal.
-For example, Perl::Critic normally only C<warn>s about profiles
-referring to non-existent Policies, but this value makes this
-situation fatal.  Correspondingly,
-L<Perl::Critic::Utils::Constants/"$PROFILE_STRICTNESS_QUIET"> makes
-Perl::Critic shut up about these things.
-
-B<-force> controls whether Perl::Critic observes the magical C<"## no
-critic"> pseudo-pragmas in your code.  If set to a true value,
-Perl::Critic will analyze all code.  If set to a false value (which is
-the default) Perl::Critic will ignore code that is tagged with these
-comments.  See L<Perl::Critic/"BENDING THE RULES"> for more
-information.
-
-B<-verbose> can be a positive integer (from 1 to 10), or a literal
-format specification.  See L<Perl::Critic::Violations> for an
-explanation of format specifications.
-
-B<-color> is not used by Perl::Critic but is provided for the benefit
-of L<perlcritic>.
-
-B<-criticism-fatal> is not used by Perl::Critic but is provided for the benefit
-of L<criticism>.
+=item C<< new(...) >>
 
+Not properly documented because you shouldn't be using this.
 
 
 =back
 
 =head1 METHODS
 
-=over 8
+=over
 
 =item C<< add_policy( -policy => $policy_name, -params => \%param_hash ) >>
 
@@ -867,79 +1003,153 @@ Creates a Policy object and loads it into this Config.  If the object
 cannot be instantiated, it will throw a fatal exception.  Otherwise,
 it returns a reference to this Critic.
 
-B<-policy> is the name of a L<Perl::Critic::Policy> subclass
-module.  The C<'Perl::Critic::Policy'> portion of the name can be
-omitted for brevity.  This argument is required.
+B<-policy> is the name of a
+L<Perl::Critic::Policy|Perl::Critic::Policy> subclass module.  The
+C<'Perl::Critic::Policy'> portion of the name can be omitted for
+brevity.  This argument is required.
 
 B<-params> is an optional reference to a hash of Policy parameters.
 The contents of this hash reference will be passed into to the
 constructor of the Policy module.  See the documentation in the
 relevant Policy module for a description of the arguments it supports.
 
+
+=item C< all_policies_enabled_or_not() >
+
+Returns a list containing references to all the Policy objects that
+have been seen.  Note that the state of these objects is not
+trustworthy.  In particular, it is likely that some of them are not
+prepared to examine any documents.
+
+
 =item C< policies() >
 
 Returns a list containing references to all the Policy objects that
-have been loaded into this Config.  Objects will be in the order that
-they were loaded.
+have been enabled and loaded into this Config.
+
 
 =item C< exclude() >
 
 Returns the value of the C<-exclude> attribute for this Config.
 
+
 =item C< include() >
 
 Returns the value of the C<-include> attribute for this Config.
 
+
 =item C< force() >
 
 Returns the value of the C<-force> attribute for this Config.
 
+
 =item C< only() >
 
 Returns the value of the C<-only> attribute for this Config.
 
+
 =item C< profile_strictness() >
 
 Returns the value of the C<-profile-strictness> attribute for this
 Config.
 
+
 =item C< severity() >
 
 Returns the value of the C<-severity> attribute for this Config.
 
+
 =item C< single_policy() >
 
 Returns the value of the C<-single-policy> attribute for this Config.
 
+
 =item C< theme() >
 
-Returns the L<Perl::Critic::Theme> object that was created for
-this Config.
+Returns the L<Perl::Critic::Theme|Perl::Critic::Theme> object that was
+created for this Config.
+
 
 =item C< top() >
 
 Returns the value of the C<-top> attribute for this Config.
 
+
 =item C< verbose() >
 
 Returns the value of the C<-verbose> attribute for this Config.
 
+
 =item C< color() >
 
 Returns the value of the C<-color> attribute for this Config.
 
+
+=item C< pager() >
+
+Returns the value of the C<-pager> attribute for this Config.
+
+
+=item C< unsafe_allowed() >
+
+Returns the value of the C<-allow-unsafe> attribute for this Config.
+
+
 =item C< criticism_fatal() >
 
-Returns the value of the C<-criticsm-fatal> attribute for this Config.
+Returns the value of the C<-criticism-fatal> attribute for this Config.
+
+
+=item C< color_severity_highest() >
+
+Returns the value of the C<-color-severity-highest> attribute for this
+Config.
+
+
+=item C< color_severity_high() >
+
+Returns the value of the C<-color-severity-high> attribute for this
+Config.
+
+
+=item C< color_severity_medium() >
+
+Returns the value of the C<-color-severity-medium> attribute for this
+Config.
+
+
+=item C< color_severity_low() >
+
+Returns the value of the C<-color-severity-low> attribute for this
+Config.
+
+
+=item C< color_severity_lowest() >
+
+Returns the value of the C<-color-severity-lowest> attribute for this
+Config.
+
+=item C< program_extensions() >
+
+Returns the value of the C<-program_extensions> attribute for this Config.
+This is an array of the file name extensions that represent program files.
+
+=item C< program_extensions_as_regexes() >
+
+Returns the value of the C<-program_extensions> attribute for this Config, as
+an array of case-sensitive regexes matching the ends of the file names that
+represent program files.
 
 =back
 
+
 =head1 SUBROUTINES
 
 Perl::Critic::Config has a few static subroutines that are used
 internally, but may be useful to you in some way.
 
-=over 8
+
+=over
 
 =item C<site_policy_names()>
 
@@ -948,24 +1158,27 @@ in the Perl::Critic:Policy namespace.  These will include modules that
 are distributed with Perl::Critic plus any third-party modules that
 have been installed.
 
+
 =back
 
+
 =head1 CONFIGURATION
 
 Most of the settings for Perl::Critic and each of the Policy modules
 can be controlled by a configuration file.  The default configuration
-file is called F<.perlcriticrc>.  L<Perl::Critic::Config> will look
-for this file in the current directory first, and then in your home
-directory.  Alternatively, you can set the C<PERLCRITIC> environment
-variable to explicitly point to a different file in another location.
-If none of these files exist, and the C<-profile> option is not given
-to the constructor, then all Policies will be loaded with their
-default configuration.
+file is called F<.perlcriticrc>.
+L<Perl::Critic::Config|Perl::Critic::Config> will look for this file
+in the current directory first, and then in your home directory.
+Alternatively, you can set the C<PERLCRITIC> environment variable to
+explicitly point to a different file in another location.  If none of
+these files exist, and the C<-profile> option is not given to the
+constructor, then all Policies will be loaded with their default
+configuration.
 
-The format of the configuration file is a series of INI-style
-blocks that contain key-value pairs separated by '='. Comments
-should start with '#' and can be placed on a separate line or after
-the name-value pairs if you desire.
+The format of the configuration file is a series of INI-style blocks
+that contain key-value pairs separated by '='. Comments should start
+with '#' and can be placed on a separate line or after the name-value
+pairs if you desire.
 
 Default settings for Perl::Critic itself can be set B<before the first
 named block.>  For example, putting any or all of these at the top of
@@ -981,6 +1194,13 @@ corresponding Perl::Critic constructor argument.
     include   = NamingConventions ClassHierarchies    #Space-delimited list
     exclude   = Variables  Modules::RequirePackage    #Space-delimited list
     color     = 1                                     #Zero or One
+    allow_unsafe = 1                                  #Zero or One
+    color-severity-highest = bold red                 #Term::ANSIColor
+    color-severity-high = magenta                     #Term::ANSIColor
+    color-severity-medium =                           #no coloring
+    color-severity-low =                              #no coloring
+    color-severity-lowest =                           #no coloring
+    program-extensions =                              #Space-delimited list
 
 The remainder of the configuration file is a series of blocks like
 this:
@@ -996,8 +1216,8 @@ C<Perl::Critic::Policy::Category::PolicyName> is the full name of a
 module that implements the policy.  The Policy modules distributed
 with Perl::Critic have been grouped into categories according to the
 table of contents in Damian Conway's book B<Perl Best Practices>. For
-brevity, you can omit the C<'Perl::Critic::Policy'> part of the
-module name.
+brevity, you can omit the C<'Perl::Critic::Policy'> part of the module
+name.
 
 C<severity> is the level of importance you wish to assign to the
 Policy.  All Policy modules are defined with a default severity value
@@ -1051,8 +1271,8 @@ A simple configuration might look like this:
     #--------------------------------------------------------------
     # I do not agree with these at all, so never load them
 
-    [-NamingConventions::ProhibitMixedCaseVars]
-    [-NamingConventions::ProhibitMixedCaseSubs]
+    [-NamingConventions::Capitalization]
+    [-ValuesAndExpressions::ProhibitMagicNumbers]
 
     #--------------------------------------------------------------
     # For all other Policies, I accept the default severity, theme
@@ -1062,46 +1282,49 @@ A simple configuration might look like this:
 For additional configuration examples, see the F<perlcriticrc> file
 that is included in this F<t/examples> directory of this distribution.
 
+
 =head1 THE POLICIES
 
 A large number of Policy modules are distributed with Perl::Critic.
 They are described briefly in the companion document
-L<Perl::Critic::PolicySummary> and in more detail in the individual
-modules themselves.
+L<Perl::Critic::PolicySummary|Perl::Critic::PolicySummary> and in more
+detail in the individual modules themselves.
+
 
 =head1 POLICY THEMES
 
-Each Policy is defined with one or more "themes".  Themes can be used to
-create arbitrary groups of Policies.  They are intended to provide an
-alternative mechanism for selecting your preferred set of Policies.  For
-example, you may wish disable a certain subset of Policies when analyzing test
-scripts.  Conversely, you may wish to enable only a specific subset of
-Policies when analyzing modules.
+Each Policy is defined with one or more "themes".  Themes can be used
+to create arbitrary groups of Policies.  They are intended to provide
+an alternative mechanism for selecting your preferred set of Policies.
+For example, you may wish disable a certain subset of Policies when
+analyzing test programs.  Conversely, you may wish to enable only a
+specific subset of Policies when analyzing modules.
 
 The Policies that ship with Perl::Critic are have been broken into the
-following themes.  This is just our attempt to provide some basic logical
-groupings.  You are free to invent new themes that suit your needs.
+following themes.  This is just our attempt to provide some basic
+logical groupings.  You are free to invent new themes that suit your
+needs.
 
     THEME             DESCRIPTION
     --------------------------------------------------------------------------
     core              All policies that ship with Perl::Critic
     pbp               Policies that come directly from "Perl Best Practices"
-    bugs              Policies that that prevent or reveal bugs
+    bugs              Policies that prevent or reveal bugs
     maintenance       Policies that affect the long-term health of the code
     cosmetic          Policies that only have a superficial effect
     complexity        Policies that specificaly relate to code complexity
     security          Policies that relate to security issues
-    tests             Policies that are specific to test scripts
-
+    tests             Policies that are specific to test programs
 
 Say C<`perlcritic -list`> to get a listing of all available policies
 and the themes that are associated with each one.  You can also change
 the theme for any Policy in your F<.perlcriticrc> file.  See the
 L<"CONFIGURATION"> section for more information about that.
 
-Using the C<-theme> option, you can combine theme names with mathematical and
-boolean operators to create an arbitrarily complex expression that represents
-a custom "set" of Policies.  The following operators are supported
+Using the C<-theme> option, you can combine theme names with
+mathematical and boolean operators to create an arbitrarily complex
+expression that represents a custom "set" of Policies.  The following
+operators are supported
 
    Operator       Alternative         Meaning
    ----------------------------------------------------------------------------
@@ -1110,7 +1333,8 @@ a custom "set" of Policies.  The following operators are supported
    +              or                  Union
 
 Operator precedence is the same as that of normal mathematics.  You
-can also use parenthesis to enforce precedence.  Here are some examples:
+can also use parenthesis to enforce precedence.  Here are some
+examples:
 
    Expression                  Meaning
    ----------------------------------------------------------------------------
@@ -1130,23 +1354,26 @@ can also use parenthesis to enforce precedence.  Here are some examples:
                                     AND "complexity"
    (pbp not bugs) and complexity  Ditto
 
-Theme names are case-insensitive.  If C<-theme> is set to an empty string,
-then it is equivalent to the set of all Policies.  A theme name that doesn't
-exist is equivalent to an empty set.  Please See
+Theme names are case-insensitive.  If C<-theme> is set to an empty
+string, then it is equivalent to the set of all Policies.  A theme
+name that doesn't exist is equivalent to an empty set.  Please See
 L<http://en.wikipedia.org/wiki/Set> for a discussion on set theory.
 
+
 =head1 SEE ALSO
 
-L<Perl::Critic::OptionsProcessor>, L<Perl::Critic::UserProfile>
+L<Perl::Critic::OptionsProcessor|Perl::Critic::OptionsProcessor>,
+L<Perl::Critic::UserProfile|Perl::Critic::UserProfile>
 
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
