@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Exception/AggregateConfiguration.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Exception::AggregateConfiguration;
 
 use 5.006001;
@@ -17,7 +10,7 @@ use Readonly;
 
 use Perl::Critic::Utils qw{ :characters };
 
-our $VERSION = '1.088';
+our $VERSION = '1.130';
 
 #-----------------------------------------------------------------------------
 
@@ -73,7 +66,7 @@ sub add_exception_or_rethrow {
     my ( $self, $eval_error ) = @_;
 
     return if not $eval_error;
-    confess $eval_error if not ref $eval_error; ## no critic (RequireUseOfExceptions)
+    confess $eval_error if not ref $eval_error;
 
     if ( $eval_error->isa('Perl::Critic::Exception::Configuration') ) {
         $self->add_exception($eval_error);
@@ -84,7 +77,7 @@ sub add_exception_or_rethrow {
         $self->add_exceptions_from($eval_error);
     }
     else {
-        die $eval_error; ## no critic (RequireUseOfExceptions, RequireCarping)
+        die $eval_error; ## no critic (RequireCarping)
     }
 
     return;
@@ -100,9 +93,9 @@ sub has_exceptions {
 
 #-----------------------------------------------------------------------------
 
-my $MESSAGE_PREFIX = $EMPTY;
-my $MESSAGE_SUFFIX = "\n";
-my $MESSAGE_SEPARATOR = $MESSAGE_SUFFIX . $MESSAGE_PREFIX;
+Readonly::Scalar my $MESSAGE_PREFIX => $EMPTY;
+Readonly::Scalar my $MESSAGE_SUFFIX => "\n";
+Readonly::Scalar my $MESSAGE_SEPARATOR => $MESSAGE_SUFFIX . $MESSAGE_PREFIX;
 
 sub full_message {
     my ( $self ) = @_;
@@ -135,6 +128,12 @@ an object for collecting all the problems found so that the user can
 see them in one run.
 
 
+=head1 INTERFACE SUPPORT
+
+This is considered to be a public class.  Any changes to its interface
+will go through a deprecation cycle.
+
+
 =head1 METHODS
 
 =over
@@ -157,10 +156,11 @@ Returns a reference to an array of the collected exceptions.
 =item C<add_exception_or_rethrow( $eval_error )>
 
 If the parameter is an instance of
-L<Perl::Critic::Exception::Configuration> or
-L<Perl::Critic::Exception::AggregateConfiguration>, add it.
-Otherwise, C<die> with the parameter, if it is a reference, or
-C<confess> with it.  If the parameter is false, simply returns.
+L<Perl::Critic::Exception::Configuration|Perl::Critic::Exception::Configuration>
+or
+L<Perl::Critic::Exception::AggregateConfiguration|Perl::Critic::Exception::AggregateConfiguration>,
+add it.  Otherwise, C<die> with the parameter, if it is a reference,
+or C<confess> with it.  If the parameter is false, simply returns.
 
 
 =item C<has_exceptions()>
@@ -183,7 +183,7 @@ Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2008 Elliot Shank.  All rights reserved.
+Copyright (c) 2007-2011 Elliot Shank.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
