@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Exception/Configuration/Option/Policy/ExtraParameter.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Exception::Configuration::Option::Policy::ExtraParameter;
 
 use 5.006001;
@@ -13,7 +6,7 @@ use warnings;
 
 use Readonly;
 
-our $VERSION = '1.088';
+our $VERSION = '1.130';
 
 #-----------------------------------------------------------------------------
 
@@ -67,8 +60,15 @@ Perl::Critic::Exception::Configuration::Option::Policy::ExtraParameter - The con
 =head1 DESCRIPTION
 
 A representation of the configuration attempting to specify a value
-for a parameter that a L<Perl::Critic::Policy> doesn't have, whether
-from a F<.perlcriticrc>, another profile file, or command line.
+for a parameter that a L<Perl::Critic::Policy|Perl::Critic::Policy>
+doesn't have, whether from a F<.perlcriticrc>, another profile file,
+or command line.
+
+
+=head1 INTERFACE SUPPORT
+
+This is considered to be a public class.  Any changes to its interface
+will go through a deprecation cycle.
 
 
 =head1 CLASS METHODS
@@ -107,7 +107,7 @@ Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2008 Elliot Shank.  All rights reserved.
+Copyright (c) 2007-2011 Elliot Shank.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
