@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/Subroutines/ProhibitBuiltinHomonyms.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Policy::Subroutines::ProhibitBuiltinHomonyms;
 
 use 5.006001;
@@ -12,23 +5,25 @@ use strict;
 use warnings;
 use Readonly;
 
-use Perl::Critic::Utils qw{ :severities :data_conversion :classification };
+use Perl::Critic::Utils qw{ :severities :data_conversion
+                            :classification :characters };
+
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.088';
+our $VERSION = '1.130';
 
 #-----------------------------------------------------------------------------
 
 Readonly::Array my @ALLOW => qw( import AUTOLOAD DESTROY );
 Readonly::Hash my %ALLOW => hashify( @ALLOW );
-Readonly::Scalar my $DESC  => q{Subroutine name is a homonym for builtin function};
+Readonly::Scalar my $DESC  => q{Subroutine name is a homonym for builtin %s %s};
 Readonly::Scalar my $EXPL  => [177];
 
 #-----------------------------------------------------------------------------
 
 sub supported_parameters { return ()                    }
 sub default_severity     { return $SEVERITY_HIGH        }
-sub default_themes       { return qw( core bugs pbp )   }
+sub default_themes       { return qw( core bugs pbp certrule )   }
 sub applies_to           { return 'PPI::Statement::Sub' }
 
 #-----------------------------------------------------------------------------
@@ -37,10 +32,20 @@ sub violates {
     my ( $self, $elem, undef ) = @_;
     return if $elem->isa('PPI::Statement::Scheduled'); #e.g. BEGIN, INIT, END
     return if exists $ALLOW{ $elem->name() };
+
+    my $homonym_type = $EMPTY;
     if ( is_perl_builtin( $elem ) ) {
-        return $self->violation( $DESC, $EXPL, $elem );
+        $homonym_type = 'function';
     }
-    return;    #ok!
+    elsif ( is_perl_bareword( $elem ) ) {
+        $homonym_type = 'keyword';
+    }
+    else {
+        return;    #ok!
+    }
+
+    my $desc = sprintf $DESC, $homonym_type, $elem->name();
+    return $self->violation($desc, $EXPL, $elem);
 }
 
 1;
@@ -51,24 +56,30 @@ __END__
 
 =pod
 
+=for stopwords perlfunc perlsyn
+
 =head1 NAME
 
 Perl::Critic::Policy::Subroutines::ProhibitBuiltinHomonyms - Don't declare your own C<open> function.
 
 =head1 AFFILIATION
 
-This Policy is part of the core L<Perl::Critic> distribution.
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
 
 
 =head1 DESCRIPTION
 
-Common sense dictates that you shouldn't declare subroutines with the
-same name as one of Perl's built-in functions. See C<`perldoc
-perlfunc`> for a list of built-ins.
+Common sense dictates that you shouldn't declare subroutines with the same
+name as one of Perl's built-in functions or keywords.  See
+L<perlfunc|perlfunc> for a list of built-in functions; see L<perlsyn|perlsyn>
+for keywords.
 
-  sub open {}  #not ok
-  sub exit {}  #not ok
-  sub print {} #not ok
+  sub open {}    #not ok
+  sub exit {}    #not ok
+  sub print {}   #not ok
+  sub foreach {} #not ok
+  sub if {}      #not ok
 
   #You get the idea...
 
@@ -90,11 +101,11 @@ subroutine is static or an object method.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
