@@ -1,10 +1,3 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Utils/POD.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
-##############################################################################
-
 package Perl::Critic::Utils::POD;
 
 use 5.006001;
@@ -22,9 +15,9 @@ use Perl::Critic::Exception::Fatal::Generic qw< throw_generic >;
 use Perl::Critic::Exception::IO qw< throw_io >;
 use Perl::Critic::Utils qw< :characters >;
 
-use base 'Exporter';
+use Exporter 'import';
 
-our $VERSION = '1.088';
+our $VERSION = '1.130';
 
 #-----------------------------------------------------------------------------
 
@@ -170,9 +163,6 @@ sub get_pod_section_for_module {
 sub _get_pod_section_from_file {
     my ($file_name, $section_name, $parser) = @_;
 
-    # Grr... the handle is open for a whopping 1 statement.  Too painful to
-    # fix the policy right now.
-    ## no critic (RequireBriefOpen)
     open my $file_handle, '<', $file_name
         or throw_io
             message     => qq<Could not open "$file_name": $ERRNO>,
@@ -189,7 +179,6 @@ sub _get_pod_section_from_file {
             message     => qq<Could not close "$file_name": $ERRNO>,
             file_name   => $file_name,
             errno       => $ERRNO;
-    ## use critic
 
     return $content;
 }
@@ -356,9 +345,6 @@ sub get_module_abstract_for_module {
 sub _get_module_abstract_from_file {
     my ($file_name, $parser, $trimmer) = @_;
 
-    # Grr... the handle is open for a whopping 1 statement.  Too painful to
-    # fix the policy right now.
-    ## no critic (RequireBriefOpen)
     open my $file_handle, '<', $file_name
         or throw_io
             message     => qq<Could not open "$file_name": $ERRNO>,
@@ -375,7 +361,6 @@ sub _get_module_abstract_from_file {
             message     => qq<Could not close "$file_name": $ERRNO>,
             file_name   => $file_name,
             errno       => $ERRNO;
-    ## use critic
 
     return $module_abstract;
 }
@@ -521,6 +506,12 @@ Perl::Critic::Utils::POD - Utility functions for dealing with POD.
 Provides means of accessing chunks of POD.
 
 
+=head1 INTERFACE SUPPORT
+
+This is considered to be a public module.  Any changes to its
+interface will go through a deprecation cycle.
+
+
 =head1 IMPORTABLE SUBROUTINES
 
 =over
@@ -545,8 +536,8 @@ contains "CZ<><$x>", the return value will contain "CZ<><$x>".
 
 Returns nothing if no such section is found.
 
-Throws a L<Perl::Critic::Exception::IO> if there's a problem with the
-file.
+Throws a L<Perl::Critic::Exception::IO|Perl::Critic::Exception::IO> if
+there's a problem with the file.
 
 
 =item C<get_raw_pod_section_from_filehandle( $file_handle, $section_name )>
@@ -566,8 +557,9 @@ that contains the raw POD.
 Does the same as C<get_raw_pod_section_from_file()>, but with a module
 name.
 
-Throws a L<Perl::Critic::Exception::Generic> if a file containing POD
-for the module can't be found.
+Throws a
+L<Perl::Critic::Exception::Generic|Perl::Critic::Exception::Generic>
+if a file containing POD for the module can't be found.
 
 
 =item C<get_pod_section_from_file( $file_name, $section_name )>
@@ -577,8 +569,8 @@ C<=head1>) from the file.  This is interpreted into plain text.
 
 Returns nothing if no such section is found.
 
-Throws a L<Perl::Critic::Exception::IO> if there's a problem with the
-file.
+Throws a L<Perl::Critic::Exception::IO|Perl::Critic::Exception::IO> if
+there's a problem with the file.
 
 
 =item C<get_pod_section_from_filehandle( $file_handle, $section_name )>
@@ -598,8 +590,9 @@ that contains the raw POD.
 Does the same as C<get_pod_section_from_file()>, but with a module
 name.
 
-Throws a L<Perl::Critic::Exception::Generic> if a file containing POD
-for the module can't be found.
+Throws a
+L<Perl::Critic::Exception::Generic|Perl::Critic::Exception::Generic>
+if a file containing POD for the module can't be found.
 
 
 =item C<trim_raw_pod_section( $pod_section )>
@@ -632,7 +625,7 @@ abstract of the module from that.  If it succeeds, it returns the
 abstract.  If it fails, either because there is no "NAME" section or
 there is no abstract after the module name, returns nothing.  If it
 looks like there's a malformed abstract, throws a
-L<Perl::Critic::Exception::Fatal::Generic>.
+L<Perl::Critic::Exception::Fatal::Generic|Perl::Critic::Exception::Fatal::Generic>.
 
 Example "well formed" "NAME" sections without abstracts:
 
@@ -699,9 +692,10 @@ name.
 
 Elliot Shank <perl@galumph.com>
 
+
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Elliot Shank.  All rights reserved.
+Copyright (c) 2008-2011 Elliot Shank.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
